@@ -122,6 +122,13 @@ class SteamApp(object):
         """
         return (self.install_path / "toolmanifest.vdf").is_file()
 
+    @property
+    def is_windows_app(self):
+        """
+        Return True if this app is a Windows app that's launched using Proton
+        """
+        return not self.is_proton and self.prefix_path_exists and self.appid
+
     @property
     def proton_dist_path(self):
         """
@@ -295,9 +302,10 @@ def find_steam_path():
 
         return None, None
 
-    # If we're inside a Flatpak sandbox, only search for it specifically
+    # If we're inside a Flatpak sandbox,
+    # prioritize Flatpak installation of Steam
     steam_dirs_to_search = (
-        [".var/app/com.valvesoftware.Steam/data/Steam"]
+        [".var/app/com.valvesoftware.Steam/data/Steam"] + COMMON_STEAM_DIRS
         if is_flatpak_sandbox()
         else COMMON_STEAM_DIRS
     )
@@ -953,6 +961,14 @@ def get_steam_apps(steam_root, steam_path, steam_lib_paths):
     steam_apps = []
 
     for path in steam_lib_paths:
+        if not path.is_dir():
+            logger.warning(
+                "Steam library folder %s not found. Protontricks "
+                "might not have access to the directory.",
+                str(path)
+            )
+            continue
+
         appmanifest_paths = []
         is_lowercase = (path / "steamapps").is_dir()
         is_mixedcase = (path / "SteamApps").is_dir()
